pub struct TailtriageControllerTemplate {
pub service_name: String,
pub config_path: Option<PathBuf>,
pub sink_template: ControllerSinkTemplate,
pub selected_mode: CaptureMode,
pub capture_limits_override: CaptureLimitsOverride,
pub strict_lifecycle: bool,
pub runtime_sampler: RuntimeSamplerTemplate,
pub run_end_policy: RunEndPolicy,
}Expand description
Template configuration that the controller applies to future activations.
Fields
service_name: StringService name attached to controller activations.
config_path: Option<PathBuf>Optional source path for reloadable control config.
sink_template: ControllerSinkTemplateSink/output template for bounded run artifacts.
selected_mode: CaptureModeMode selected for next activations.
capture_limits_override: CaptureLimitsOverrideField-level capture limits override applied on top of mode defaults.
strict_lifecycle: boolStrict lifecycle behavior for next activations.
runtime_sampler: RuntimeSamplerTemplateRuntime sampler template for next activations.
run_end_policy: RunEndPolicyPolicy that determines how an activation run should end.